@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: mapfile.h 11177 2011-03-16 19:29:01Z sdlime $
+ * $Id$
  *
  * Project:  MapServer
  * Purpose:  Keyword definitions for the mapfiles and symbolfiles.
@@ -15,7 +15,7 @@
  * and/or sell copies of the Software, and to permit persons to whom the
  * Software is furnished to do so, subject to the following conditions:
  *
- * The above copyright notice and this permission notice shall be included in 
+ * The above copyright notice and this permission notice shall be included in
  * all copies of this Software or works derived from this Software.
  *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
@@ -207,14 +207,14 @@ enum MS_TOKEN_SOURCES {MS_FILE_TOKENS=0, MS_STRING_TOKENS, MS_URL_TOKENS};
 #define FILEPATTERN 1151
 #define TEMPLATEPATTERN 1152
 
-#define PROCESSING	1153
+#define PROCESSING  1153
 
 /* The DEBUG macro is also used to request debugging output.  Redefine
    for keyword purposes.  */
 
 #ifdef DEBUG
 #undef DEBUG
-#endif 
+#endif
 
 #define DEBUG 1154
 
@@ -234,7 +234,7 @@ enum MS_TOKEN_SOURCES {MS_FILE_TOKENS=0, MS_STRING_TOKENS, MS_URL_TOKENS};
 
 #define OUTLINEWIDTH 1166
 
- /* Color Range support (was Gradient Support)*/
+/* Color Range support (was Gradient Support)*/
 #define COLORRANGE 1170
 #define DATARANGE 1172
 #define RANGEITEM 1173
@@ -297,7 +297,19 @@ enum MS_TOKEN_SOURCES {MS_FILE_TOKENS=0, MS_STRING_TOKENS, MS_URL_TOKENS};
 #define MAXDISTANCE 1227
 #define REGION 1228
 
+#define INITIALGAP 1229
+#define ANCHORPOINT 1230
+
+#define MASK 1250
+
+#define POLAROFFSET 1251
+
+/* rfc78 leader-lines labels */
+#define LEADER 1260
+#define GRIDSTEP 1261
+
 /* rfc59 bindvals objects */
 #define BINDVALS 2000
 
+
 #endif /* MAPFILE_H */
