@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: mapsymbol.h 11599 2011-04-19 05:14:17Z tbonfort $
+ * $Id$
  *
  * Project:  MapServer
  * Purpose:  symbolObj related declarations.
@@ -15,7 +15,7 @@
  * and/or sell copies of the Software, and to permit persons to whom the
  * Software is furnished to do so, subject to the following conditions:
  *
- * The above copyright notice and this permission notice shall be included in 
+ * The above copyright notice and this permission notice shall be included in
  * all copies of this Software or works derived from this Software.
  *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
@@ -30,7 +30,10 @@
 #ifndef MAPSYMBOL_H
 #define MAPSYMBOL_H
 
+#ifdef USE_GD
 #include <gd.h>
+#endif
+
 #include <assert.h>
 
 enum MS_SYMBOL_TYPE {MS_SYMBOL_SIMPLE=1000, MS_SYMBOL_VECTOR, MS_SYMBOL_ELLIPSE, MS_SYMBOL_PIXMAP, MS_SYMBOL_TRUETYPE, MS_SYMBOL_HATCH, MS_SYMBOL_SVG};
@@ -43,7 +46,9 @@ enum MS_SYMBOL_TYPE {MS_SYMBOL_SIMPLE=1000, MS_SYMBOL_VECTOR, MS_SYMBOL_ELLIPSE,
 
 /* COLOR OBJECT */
 typedef struct {
+#ifdef USE_GD
   int pen;
+#endif
   int red;
   int green;
   int blue;
@@ -54,38 +59,40 @@ typedef struct {
 enum MS_RASTER_BUFFER_TYPE { MS_BUFFER_NONE=2000, MS_BUFFER_BYTE_RGBA, MS_BUFFER_BYTE_PALETTE, MS_BUFFER_GD };
 
 typedef struct {
-	unsigned char *pixels;
-	unsigned int pixel_step, row_step;
-	unsigned char *a,*r,*g,*b;
+  unsigned char *pixels;
+  unsigned int pixel_step, row_step;
+  unsigned char *a,*r,*g,*b;
 } rgbaArrayObj;
 
 typedef struct {
-    unsigned char b,g,r,a;
+  unsigned char b,g,r,a;
 } rgbaPixel;
 
 typedef struct {
-    unsigned char r,g,b;
+  unsigned char r,g,b;
 } rgbPixel;
 
 
 typedef struct {
-	unsigned char *pixels; /*stores the actual pixel indexes*/
-	rgbaPixel *palette; /*rgba palette entries*/
-	unsigned int num_entries; /*number of palette entries*/
-   unsigned int scaling_maxval;
+  unsigned char *pixels; /*stores the actual pixel indexes*/
+  rgbaPixel *palette; /*rgba palette entries*/
+  unsigned int num_entries; /*number of palette entries*/
+  unsigned int scaling_maxval;
 } paletteArrayObj;
 
 typedef struct {
-	int type;
-	unsigned int width,height;
-	union {
-		rgbaArrayObj rgba;
-		paletteArrayObj palette;
-		gdImagePtr gd_img;
-	} data;
+  int type;
+  unsigned int width,height;
+  union {
+    rgbaArrayObj rgba;
+    paletteArrayObj palette;
+#ifdef USE_GD
+    gdImagePtr gd_img;
+#endif
+  } data;
 } rasterBufferObj;
 
-/* NOTE: RB_SET_PIXEL() will premultiply by alpha, inputs should not be 
+/* NOTE: RB_SET_PIXEL() will premultiply by alpha, inputs should not be
          premultiplied */
 
 #define RB_SET_PIXEL(rb,x,y,red,green,blue,alpha) \
@@ -117,7 +124,7 @@ typedef struct {
         } \
     }
 
-/* NOTE: RB_MIX_PIXEL() will premultiply by alpha, inputs should not be 
+/* NOTE: RB_MIX_PIXEL() will premultiply by alpha, inputs should not be
          premultiplied */
 
 #define RB_MIX_PIXEL(rb,x,y,red,green,blue,alpha) \
@@ -156,7 +163,7 @@ typedef struct {
   /*
   ** Pointer to his map
   */
-  struct map_obj *map;
+  struct mapObj *map;
 #endif /* SWIG */
   /*
   ** MS_SYMBOL_VECTOR and MS_SYMBOL_ELLIPSE options
@@ -177,7 +184,9 @@ typedef struct {
   %mutable;
 #endif /* SWIG */
   int filled;
-  
+
+  double anchorpoint_x, anchorpoint_y;
+
   /*
   ** MS_SYMBOL_PIXMAP options
   */
